.. _sec_examples:

========
Examples
========

These are examples for the bare afmformats package. You might find other
examples interesting to you in the :ref:`nanite documentation <nanite:sec_examples>`.

.. toctree::
  :maxdepth: 2


.. fancy_include:: stress_relaxation.py
